<?php
/**
 * Plugin Name: WP Twitter Timeline
 * Plugin URI: http://blog.ppfeufer.de/wordpress-plugin-wp-twitter-timeline/
 * Description: Add a sidebarwidget with your twitter timeline to your WordPress-Blog.
 * Version: 1.0.1
 * Author: H.-Peter Pfeufer
 * Author URI: http://ppfeufer.de
 */

/**
 * Changelog
 * = 1.0.1 (08.01.2011) =
 * Update: JavaScript
 *
 * = 1.0.0 (07.01.2011) =
 * Initial Release.
 * Added widget-settings.
 */

if(!defined('PPFEUFER_FLATTRSCRIPT')) {
	define('PPFEUFER_FLATTRSCRIPT', 'http://cdn.ppfeufer.de/js/flattr/flattr.js');
}
define('WP_TWITTER_TIMELINE_VERSION', '1.0.1');

class Wp_Twitter_Timeline extends WP_Widget {
	/**
	 * Einige notwendige Variablen definieren
	 */
	protected $var_sPluginDir = '../wp-content/plugins/wp-twitter-timeline/';

	/**
	 * Constructor
	 */
	function Wp_Twitter_Timeline() {
		if(function_exists('load_plugin_textdomain')) {
			load_plugin_textdomain('wp-twitter-timeline', PLUGINDIR . '/' . dirname(plugin_basename(__FILE__)) . '/l10n', dirname(plugin_basename(__FILE__)) . '/l10n');
		}

		$widget_ops = array(
			'classname' => 'wp_twitter_timeline',
			'description' => __('Adds a twitter timeline to your blog', 'wp-twitter-timeline')
		);

		$control_ops = array(
			'width' => 200
		);

		$this->WP_Widget('wp_twitter_timeline', __('WP Twitter Timeline', 'wp-twitter-timeline'), $widget_ops, $control_ops);
	}

	/**
	 * Widgetformular erstellen
	 * @param $instance
	 */
	function form($instance) {
		$instance = wp_parse_args((array) $instance, array(
			'title' => '',
			'twittername' => '',
			'number-of-tweets' => '5',
			'height' => '300'
		));

//		$title = strip_tags($instance['title']);
		$poll_results = ($instance['poll-results'] == 'true') ? 'checked="checked"' : '';
		$scrollbar = ($instance['scrollbar'] == 'true') ? 'checked="checked"' : '';
		$avatars = ($instance['avatars'] == 'true') ? 'checked="checked"' : '';
		$timestamps = ($instance['timestamps'] == 'true') ? 'checked="checked"' : '';
		$hashtags = ($instance['hashtags'] == 'true') ? 'checked="checked"' : '';
		$timed_interval = ($instance['behavior'] == 'default') ? ' checked="checked"' : '';
		$repeat_tweets = ($instance['repeat-tweets'] == 'true') ? ' checked="checked"' : '';
		$load_all_tweets = ($instance['behavior'] == 'all') ? ' checked="checked"' : '';
		$height_auto = ($instance['height-auto'] == 'true') ? ' checked="checked"' : '';

		// Title
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>' . __('Title:', 'wp-twitter-timeline') . '</strong></p>';
		echo '<p><input id="' . $this->get_field_id('title') . '" name="' . $this->get_field_name('title') . '" type="text" value="' . strip_tags($instance['title']) . '" /></p>';
		echo '<p style="clear:both;"></p>';

		// User-Settings
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>' . __('User-Settings:', 'wp-twitter-timeline') . '</strong></p>';
		echo '<p><span style="display:inline-block;">' . __('Twittername <em>(without @)</em>', 'wp-twitter-timeline') . ': </span><input id="' . $this->get_field_id('twittername') . '" name="' . $this->get_field_name('twittername') . '" type="text" value="' . $instance['twittername'] . '" /></p>';
		echo '<p><span style="display:inline-block;">' . __('Number of tweets', 'wp-twitter-timeline') . ': </span><input id="' . $this->get_field_id('number-of-tweets') . '" name="' . $this->get_field_name('number-of-tweets') . '" type="text" value="' . $instance['number-of-tweets'] . '" /></p>';
		echo '<p style="clear:both;"></p>';

		// Preferences
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>' . __('Preferences:', 'wp-twitter-timeline') . '</strong></p>';
		echo '<p><input class="checkbox" type="checkbox" ' . $poll_results . ' id="' . $this->get_field_id('poll-results') . '" name="' . $this->get_field_name('poll-results') . '" /> <span style="display:inline-block;">' . __('Poll for new results?', 'wp-twitter-timeline') . '</span></p>';
		echo '<p><input class="checkbox" type="radio" ' . $timed_interval . ' value="default" id="' . $this->get_field_id('behavior') . '" name="' . $this->get_field_name('behavior') . '" group="behaviour" onchange="wpWidgets.save(jQuery(this).closest(\'div.widget\'),0,1,0);" /> <span style="display:inline-block;">' . __('Timed Interval?', 'wp-twitter-timeline') . '</span></p>';

		if($timed_interval != '') {
			echo '<p><input class="checkbox" type="checkbox" ' . $repeat_tweets . ' id="' . $this->get_field_id('repeat-tweets') . '" name="' . $this->get_field_name('repeat-tweets') . '" /> <span style="display:inline-block;">' . __('Repeat Tweets?', 'wp-twitter-timeline') . '</span></p>';
			echo '<p><span style="display:inline-block;">' . __('Tweet Interval <em>(Seconds)</em>', 'wp-twitter-timeline') . ': </span><input id="' . $this->get_field_id('tweet-interval') . '" name="' . $this->get_field_name('tweet-interval') . '" type="text" value="' . $instance['tweet-interval'] . '" /></p>';
		}

		echo '<p><input class="checkbox" type="radio" ' . $load_all_tweets . ' value="all" id="' . $this->get_field_id('behavior') . '" name="' . $this->get_field_name('behavior') . '" group="behaviour" onchange="wpWidgets.save(jQuery(this).closest(\'div.widget\'),0,1,0);" /> <span style="display:inline-block;">' . __('Load all tweets?', 'wp-twitter-timeline') . '</span></p>';
		echo '<p><input class="checkbox" type="checkbox" ' . $scrollbar . ' id="' . $this->get_field_id('scrollbar') . '" name="' . $this->get_field_name('scrollbar') . '" /> <span style="display:inline-block;">' . __('Include scrollbar?', 'wp-twitter-timeline') . '</span></p>';
		echo '<p><input class="checkbox" type="checkbox" ' . $avatars . ' id="' . $this->get_field_id('avatars') . '" name="' . $this->get_field_name('avatars') . '" /> <span style="display:inline-block;">' . __('Show Avatars?', 'wp-twitter-timeline') . '</span></p>';
		echo '<p><input class="checkbox" type="checkbox" ' . $timestamps . ' id="' . $this->get_field_id('timestamps') . '" name="' . $this->get_field_name('timestamps') . '" /> <span style="display:inline-block;">' . __('Show Timestamps?', 'wp-twitter-timeline') . '</span></p>';
		echo '<p><input class="checkbox" type="checkbox" ' . $hashtags . ' id="' . $this->get_field_id('hashtags') . '" name="' . $this->get_field_name('hashtags') . '" /> <span style="display:inline-block;">' . __('Show Hashtags?', 'wp-twitter-timeline') . '</span></p>';
		echo '<p style="clear:both;"></p>';

		// Widget-Settings
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>' . __('Dimension:', 'wp-twitter-timeline') . '</strong></p>';
		echo '<p><span style="display:inline-block;">' . __('Height <em>(in pixel)</em>', 'wp-twitter-timeline') . ': </span><input id="' . $this->get_field_id('height') . '" name="' . $this->get_field_name('height') . '" type="text" value="' . $instance['height'] . '" /></p>';
		echo '<p style="clear:both;"></p>';

		// #Colors
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>#' . __('Colors:', 'wp-twitter-timeline') . '</strong></p>';
		echo '<p><span style="display:inline-block;">' . __('Textcolor', 'wp-twitter-timeline') . ': </span><input id="' . $this->get_field_id('textcolor') . '" name="' . $this->get_field_name('textcolor') . '" type="text" value="' . $instance['textcolor'] . '" /></p>';
		echo '<p><span style="display:inline-block;">' . __('Linkcolor', 'wp-twitter-timeline') . ': </span><input id="' . $this->get_field_id('linkcolor') . '" name="' . $this->get_field_name('linkcolor') . '" type="text" value="' . $instance['linkcolor'] . '" /></p>';
		echo '<p style="clear:both;"></p>';

		// Own CSS
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>' . __('Custom CSS:', 'wp-twitter-timeline') . '</strong></p>';
		echo '<p><span style="display:inline-block;">' . __('Write your CSS here ...', 'wp-twitter-timeline') . ': </span><textarea id="' . $this->get_field_id('own-css') . '" rows="10" name="' . $this->get_field_name('own-css') . '">' . $instance['own-css'] . '</textarea></p>';
		echo '<p style="clear:both;"></p>';

		// Flattr
		echo '<p style="clear:both;"></p>';
		echo '<p style="border-bottom: 1px solid #DFDFDF;"><strong>' . __('Like this Plugin? Support the developer.', 'wp-twitter-timeline') . '</strong></p>';
		echo '<p><a class="FlattrButton" style="display:none;" rev="flattr;button:compact;" href="http://blog.ppfeufer.de/wordpress-plugin-wp-twitter-timeline/"></a></p>';
		echo '<p style="clear:both;"></p>';
	}

	/**
	 * Widget erstellen
	 * @param unknown_type $args
	 * @param unknown_type $instance
	 */
	function widget($args, $instance) {
		extract($args);

		echo $before_widget;

		$title = (empty($instance['title'])) ? '&nbsp;' : apply_filters('widget_title', $instance['title']);

		if(!empty($title)) {
			echo $before_title . $title . $after_title;
		}

		echo $this->wp_twitter_timeline_output($instance, 'widget');
		echo $after_widget;
	}

	/**
	 * Optionen updaten
	 * @param $new_instance
	 * @param $old_instance
	 */
	function update($new_instance, $old_instance) {
		$instance = $old_instance;

		$new_instance = wp_parse_args((array) $new_instance, array(
			'title' => '',
			'twittername' => '',
			'number-of-tweets' => '5',
			'height' => '300'
		));

		$instance['title'] = strip_tags($new_instance['title']);
		$instance['twittername'] = strip_tags($new_instance['twittername']);
		$instance['number-of-tweets'] = strip_tags($new_instance['number-of-tweets']);
		$instance['height'] = strip_tags($new_instance['height']);
		$instance['textcolor'] = strip_tags($new_instance['textcolor']);
		$instance['linkcolor'] = strip_tags($new_instance['linkcolor']);
		$instance['poll-results'] = $new_instance['poll-results'] ? 'true' : 'false';
		$instance['liveupdate'] = $new_instance['liveupdate'] ? 'true' : 'false';
		$instance['scrollbar'] = $new_instance['scrollbar'] ? 'true' : 'false';
		$instance['avatars'] = $new_instance['avatars'] ? 'true' : 'false';
		$instance['timestamps'] = $new_instance['timestamps'] ? 'true' : 'false';
		$instance['hashtags'] = $new_instance['hashtags'] ? 'true' : 'false';
		$instance['repeat-tweets'] = $new_instance['repeat-tweets'] ? 'true' : 'false';
		$instance['tweet-interval'] = strip_tags($new_instance['tweet-interval']);
		$instance['behavior'] = $new_instance['behavior'];
		$instance['own-css'] = $new_instance['own-css'];

		return $instance;
	}

	function wp_twitter_timeline_output($args = array(), $position) {
		?>
		<script src="http://widgets.twimg.com/j/2/widget.js"></script>
		<script>
		new TWTR.Widget({
			version: 2,
			type: 'profile',
			<?php if ($args['footer-text'] != '') : ?>
			footer: "Follow me",
			<?php endif; ?>
			rpp: <?php echo $args['number-of-tweets'] ?>,
			interval: <?php echo $args['tweet-interval'] ?>000,
			width: 'auto',
			height: <?php echo $args['height'] ?>,
			theme: {
				shell: {
					background: 'none',
					color: '<?php echo $args['textcolor'] ?>'
				},
				tweets: {
					background: 'none',
					color: '<?php echo $args['textcolor'] ?>',
					links: '<?php echo $args['linkcolor'] ?>'
				}
			},
			features: {
				scrollbar: <?php echo $args['scrollbar'] ?>,
				loop: <?php echo $args['repeat-tweets'] ?>,
				live: <?php echo $args['poll-results'] ?>,
				hashtags: <?php echo $args['hashtags'] ?>,
				timestamp: <?php echo $args['timestamps'] ?>,
				avatars: <?php echo $args['avatars'] ?>,
				behavior: '<?php echo $args['behavior'] ?>'
			}
		}).render().setUser('<?php echo $args['twittername']; ?>').start();
		</script>
		<?php
	}
}

add_action('widgets_init', create_function('', 'return register_widget("Wp_Twitter_Timeline");'));

/**
 * CSS einbinden
 */
if(!is_admin()) {
	/* Header um CSS erweitern, sofern in der Datenbank hinterlegt */
	function wp_twitter_timeline_head() {
		$array_widgetOptions = get_option('widget_wp_twitter_timeline');
		// CSS suchen
		foreach($array_widgetOptions as $key => $value) {
			if($value['own-css']) {
				$var_sOwnCSS = $value['own-css'];
				break;
			}
		}

		if($var_sOwnCSS != '') {
			// CSS in den Header einfügen
			echo "\n" . '<!-- CSS for WP Twitter Timeline by H.-Peter Pfeufer [http://ppfeufer.de | http://blog.ppfeufer.de] -->' . "\n" . '<style type="text/css">' . "\n" . $var_sOwnCSS . "\n" . '</style>' . "\n" . '<!-- END of CSS for WP Twitter Timeline -->' . "\n\n";
		}
	}

	add_action('wp_head', 'wp_twitter_timeline_head');
} else {
	/**
	 * JavaScript für Flattr einfügen
	 */
	wp_enqueue_script('flattrscript', PPFEUFER_FLATTRSCRIPT);
}
?>